@@ -35,8 +35,6 @@ class Mlb:
     ----------
     hostname: str
         hostname of statsapi.mlb.com
-    ver: str
-        api version
     logger: logging.Loger
         logger
     """
@@ -1716,7 +1714,7 @@ class Mlb:
             for season in mlb_data.data['seasons']:
                 return Season(**season)
 
-    def get_seasons(self, sport_id: int = None, **params) -> List[Season]:
+    def get_seasons(self, sport_id: int = 1, **params) -> List[Season]:
         """
         return a season object for sportid
 
@@ -1857,7 +1855,7 @@ class Mlb:
 
 
     def get_attendance(self, team_id: int = None, league_id: int = None,
-                       league_list_id: int = None, 
+                       league_list_id: str = None, 
                        **params) -> Union[Attendance, None]:
         """
         returns attendance data based on teamId, leagueId, or leagueListId.
@@ -1869,7 +1867,7 @@ class Mlb:
         league_id : int
             Insert leagueId(s) to return a directory of attendanace for a 
             specific league. Format '103,104'
-        league_list_id : int
+        league_list_id : str
             Insert a unique League List Identifier to return a directory of 
             attendanace for a specific league listId.
             Available values : milb_full, milb_short, milb_complex, milb_all, 
@@ -1977,7 +1975,7 @@ class Mlb:
                     round_list.append(Round(**round))
         return round_list
 
-    def get_awards(self, award_id: int, **params) -> List[Award]:
+    def get_awards(self, award_id: str, **params) -> List[Award]:
         """
         return a list of awards for award_id
 
@@ -1990,9 +1988,9 @@ class Mlb:
         ----------------
         sportId : int
             Insert a sportId to return a directory of players for a given award in a specific sport.
-        leagueId : 
+        leagueId : int, List[int]
             Insert leagueId(s) to return a directory of players for a given award in a specific league. Format '103,104'
-        season : int
+        season : int, List[int]
             Insert year(s) to return a directory of players for a given award in a given season. Format '2016,2017'
 
         Returns
@@ -2100,9 +2098,10 @@ class Mlb:
             return {}
 
         if 'stats' in mlb_data.data and mlb_data.data['stats']:
-            groups = mlb_module.build_group_list(params)
-            splits = mlb_module.create_split_data(mlb_data.data['stats'], groups)
-
+            splits = mlb_module.create_split_data(mlb_data.data['stats'])
+        else:
+            return {}
+            
         return splits
 
     def get_players_stats_for_game(self, person_id: int, game_id: int, **params) -> dict:
@@ -2138,22 +2137,15 @@ class Mlb:
         >>> print(stats['stats']['gamelog'])
         >>> print(stats['hitting']['playlog'])
         """
-        # this endpoint is very inconsitent
-        # so we'll just make it work
-        
-        # set stat groups
-        # game stats should return a playlog, vsplayer5y, or gameLog stat objects
-        params['group'] = ['hitting', 'pitching', 'stats']
-        params['stats'] = ['playLog', 'vsPlayer5Y', 'gameLog']
-
         mlb_data = self._mlb_adapter_v1.get(endpoint=f'people/{person_id}/stats/game/{game_id}')
         if 400 <= mlb_data.status_code <= 499:
             return {}
 
         if 'stats' in mlb_data.data and mlb_data.data['stats']:
-            groups = mlb_module.build_group_list(params)
-            splits = mlb_module.create_split_data(mlb_data.data['stats'], groups)
-
+            splits = mlb_module.create_split_data(mlb_data.data['stats'])
+        else:
+            return {}
+            
         return splits
         
     def get_player_stats(self, person_id: int, stats: list, groups: list, **params) -> dict:
@@ -2204,8 +2196,9 @@ class Mlb:
             return {}
 
         if 'stats' in mlb_data.data and mlb_data.data['stats']:
-            groups = mlb_module.build_group_list(params)
-            splits = mlb_module.create_split_data(mlb_data.data['stats'], groups)
+            splits = mlb_module.create_split_data(mlb_data.data['stats'])
+        else:
+            return {}
 
         return splits
 
@@ -2256,14 +2249,16 @@ class Mlb:
         """
         params['stats'] = stats
         params['group'] = groups
+
         mlb_data = self._mlb_adapter_v1.get(endpoint='stats', ep_params=params)
         if 400 <= mlb_data.status_code <= 499:
             return {}
 
         if 'stats' in mlb_data.data and mlb_data.data['stats']:
-            groups = mlb_module.build_group_list(params)
-            splits = mlb_module.create_split_data(mlb_data, groups)
-
+            splits = mlb_module.create_split_data(mlb_data)
+        else:
+            return {}
+            
         return splits
 
 
