@@ -44,7 +44,7 @@ class GameDataGame:
     seasondisplay: str
 
 
-@dataclass
+@dataclass(repr=False)
 class GameDatetime:
     """
     A class to represent the date time for this game.
@@ -75,6 +75,10 @@ class GameDatetime:
     resumedfromdate: Optional[str] = None
     resumedfromdatetime: Optional[str] = None
 
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
+
 @dataclass
 class GameStatus:
     """
@@ -113,9 +117,9 @@ class GameTeams:
 
     Attributes
     ----------
-    away : GameTeam
+    away : Team
         Away team
-    home : GameTeam
+    home : Team
         Home team
     """
     away: Union[Team, dict]
