@@ -8,7 +8,7 @@ from mlbstatsapi.models.sports import Sport
 from .attributes import Teamrecords
 
 
-@dataclass
+@dataclass(repr=False)
 class Standings:
     """
     A class representing a standings in a league.
@@ -20,7 +20,7 @@ class Standings:
         A string indicating the type of standings.
     league : league
         An object containing information about the league.
-    division : Sport
+    division : Division
         An object containing information about the division
     sport : Sport
         An object containing information about the sport.
@@ -40,4 +40,8 @@ class Standings:
         self.league = League(**self.league)
         self.division = Division(**self.division)
         self.sport = Sport(**self.sport) if self.sport else None
-        self.teamrecords = [Teamrecords(**teamrecord) for teamrecord in self.teamrecords]
\ No newline at end of file
+        self.teamrecords = [Teamrecords(**teamrecord) for teamrecord in self.teamrecords]
+
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
\ No newline at end of file
