@@ -1,4 +1,4 @@
 ﻿from dataclasses import dataclass, field
 from typing import Optional, Union
 
-from .stats import Stats
\ No newline at end of file
+from .stats import Splits
\ No newline at end of file
